
#--EHF     
#--FILE: aliases.nawk 
#--
#-- Usage: nawk -f aliases.nawk INFILE > OUTFILE
#--
#--    "INFILE" is the file being read (in this case the aliases file)
#--    "OUTFILE" is the where output will be saved 
#--
#-- After generating the LDIF file, import it into the Directory Server with:
#--
#--  ldapmodify -a -D "cn=Directory Manager" -w PASSWORD -h HOST -p PORT -f OUTFILE
#--


{

  while (getline)
  {

	#
	# split line being read into two fields;
	# white-space is default delimiter;
	# example -->
	# The follwing line:
	#    user: user@domain.com
	# would be split into: 
	#   key[1]	key[2]
	#   user:	user@domain.com
	#
	split($0, key);
	
	# get rid of ':' from first field
	sub(/:/, "", key[1]); 

	#
	# count the number of chars in key
	#
	key_char_count = length(key[1]);

	# 
	# split key[2] using ',' as delimiter;
	# example -->
	# The following line:
	#    user1,user2,user3
	# would be split into:
	#   entry[1]	entry[2]    entry[3]
	#   user1	user2	    user3	
	#
	# An entry that only contains one address would
	# be split OK also.
	# 
	num_elements = split(key[2], entry, /,/); 
	
	#
	# print LDIF data for all aliases
	#
   	printf("dn: cn=%s, ou=aliases, ou=Sendmail, ou=Services, o=cypress.com\n", key[1]);
   	printf("objectclass: top\n");
   	printf("objectclass: mailGroup\n");
   	printf("cn: %s\n", key[1]);
   	printf("mail: %s\n", key[1]); 
   	printf("mailhost: mailhost.mis.cypress.com\n");
   	for (i=1; i <= num_elements; i++)
   	{	
	    printf("mgrprfc822mailmember: %s\n", entry[i]);   
   	}
   	printf("\n");


  } # while

}
 